@@ -23,7 +23,10 @@ class JSONStreamerException(Exception):
         self._msg = msg
 
     def __str__(self):
-        return self._msg
+        if isinstance(self._msg, str):
+            return self._msg
+        else:
+            return self._msg.decode("utf-8")
 
 
 class JSONStreamer(events.EventSource, YajlListener):
@@ -142,8 +145,8 @@ class JSONStreamer(events.EventSource, YajlListener):
             raise RuntimeError('Invalid json-streamer state')
 
     def on_number(self, ctx, value):
-        """ Since this is defined both integer and double callbacks are useless """
-        value = float(value) if '.' in value else int(value)
+        ''' Since this is defined both integer and double callbacks are useless '''
+        value = int(value) if value.isdigit() else float(value)
         top = self._stack[-1]
         if top is JSONCompositeType.OBJECT:
             self.fire(JSONStreamer.VALUE_EVENT, value)
